@@ -2,7 +2,7 @@
 #
 #       exports.py
 #
-#       Copyright 2009-2018 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2020 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -585,13 +585,19 @@ class Export2Html:
         self.new_path = os.path.join(dir_place, new_folder)
         self.images_dir = os.path.join(self.new_path, "images")
         self.embed_dir = os.path.join(self.new_path, "EmbeddedFiles")
+        self.res_dir = os.path.join(self.new_path, "res")
         os.mkdir(self.new_path)
         os.mkdir(self.images_dir)
         os.mkdir(self.embed_dir)
-        styles_css_filepath = os.path.join(cons.CONFIG_DIR, "styles.css")
+        os.mkdir(self.res_dir)
+        styles_css_filepath = os.path.join(cons.CONFIG_DIR, "styles2.css")
         if not os.path.isfile(styles_css_filepath):
-            shutil.copy(os.path.join(cons.GLADE_PATH, "styles.css"), cons.CONFIG_DIR)
-        shutil.copy(styles_css_filepath, self.new_path)
+            shutil.copy(os.path.join(cons.GLADE_PATH, "styles2.css"), cons.CONFIG_DIR)
+        script_js_filepath = os.path.join(cons.CONFIG_DIR, "script.js")
+        if not os.path.isfile(script_js_filepath):
+            shutil.copy(os.path.join(cons.GLADE_PATH, "script.js"), cons.CONFIG_DIR)
+        shutil.copy(styles_css_filepath, self.res_dir)
+        shutil.copy(script_js_filepath, self.res_dir)
         return True
 
     def nodes_all_export_to_html(self, top_tree_iter=None):
@@ -599,17 +605,21 @@ class Export2Html:
         # create tree links text
         self.tree_links_nums = ["1"]
         shutil.copy(os.path.join(cons.GLADE_PATH, "home.png"), self.images_dir)
-        pango_font = pango.FontDescription(self.dad.tree_font)
         self.tree_links_text = '<div class="tree">\n'
-        self.tree_links_text += '<p><strong>Index</strong></p>\n'
+        self.tree_links_text += '''<p>
+<strong>Index</strong></br>
+<button onclick="expandAllSubtrees()">Expand All</button> <button onclick="collapseAllSubtrees()">Collapse All</button>
+</p>\n'''
         if not top_tree_iter: tree_iter = self.dad.treestore.get_iter_first()
         else: tree_iter = top_tree_iter.copy()
         self.tree_count_level = 1
+        self.tree_links_text += '<ul class="outermost">\n'
         while tree_iter:
-            self.tree_links_text_iter(tree_iter)
+            self.tree_links_text += self.tree_links_text_iter(tree_iter)
             self.tree_links_nums[-1] = str( int(self.tree_links_nums[-1]) + 1 )
             if top_tree_iter: break
             tree_iter = self.dad.treestore.iter_next(tree_iter)
+        self.tree_links_text += '</ul>\n'
         if self.tree_count_level > 1:
             print self.tree_count_level-1
             self.tree_links_text += '</ol>'*(self.tree_count_level-1)
@@ -636,38 +646,74 @@ class Export2Html:
 
     def tree_links_text_iter(self, tree_iter):
         """Creating the Tree Links Text - iter"""
+        if(not tree_iter): return ""
         href = self.get_html_filename(tree_iter)
         node_name = clean_text_to_utf8(self.dad.treestore[tree_iter][1])
-        if self.tree_count_level < len(self.tree_links_nums):
-            self.tree_count_level += 1
-            self.tree_links_text += '<ol>\n'
-        elif self.tree_count_level > len(self.tree_links_nums):
-            i = self.tree_count_level - len(self.tree_links_nums)
-            self.tree_links_text += '</ol>\n' * i
-            self.tree_count_level -= i
-        if self.tree_count_level == 1:
-            self.tree_links_text += '<p><a href="' + href + '">' + node_name + '</a></p>\n'
-        else:
-            self.tree_links_text += '<li><a href="' + href + '">' + node_name + '</a></li>'
-        self.tree_links_text += '\n'
         child_tree_iter = self.dad.treestore.iter_children(tree_iter)
-        self.tree_links_nums.append("1")
+        if(not child_tree_iter):
+            return '''<li class="leaf"><a href="#" onclick="changeFrame('%s')">%s</a></li>\n''' % (href, node_name)
+        html = '''<li><button onclick="toggleSubTree(this)">-</button> <a href="#" onclick="changeFrame('%s')">%s</a></li>
+''' % (href, node_name)
+        html += '<ul class="subtree">\n'
         while child_tree_iter:
-            self.tree_links_text_iter(child_tree_iter)
-            self.tree_links_nums[-1] = str( int(self.tree_links_nums[-1]) + 1 )
+            html += self.tree_links_text_iter(child_tree_iter)
             child_tree_iter = self.dad.treestore.iter_next(child_tree_iter)
-        self.tree_links_nums.pop()
+        html += '</ul>\n'
+        return html
 
     def create_tree_index_page(self):
         """Write the index html file for the tree"""
         html_text = cons.HTML_HEADER % self.dad.file_name
+        html_text += '''<div class="main">\n'''
         html_text += self.tree_links_text
+        html_text += '''<div class="page">
+        <iframe class="page" src="" id="page_frame"></iframe>
+    </div>
+</div>'''
+        html_text += '<script src="res/script.js"></script>\n'
         html_text += cons.HTML_FOOTER
         file_descriptor = open(os.path.join(self.new_path, "index.html"), 'w')
         file_descriptor.write(html_text)
         file_descriptor.close()
 
     def node_export_to_html(self, tree_iter, only_selection=False):
+        """Export a Node To HTML"""
+        if only_selection:
+            iter_start, iter_end = self.dad.curr_buffer.get_selection_bounds()
+            sel_range = [iter_start.get_offset(), iter_end.get_offset()]
+        else: sel_range = None
+        html_text = cons.HTML_HEADER % clean_text_to_utf8(self.dad.treestore[tree_iter][1])
+        if self.tree_links_text and self.dad.last_index_in_page:
+            html_text += ''
+        if self.dad.last_include_node_name:
+            html_text += '<h1><b><u>%s</u></b></h1>' % clean_text_to_utf8(self.dad.treestore[tree_iter][1])
+        self.dad.get_textbuffer_from_tree_iter(tree_iter)
+        if self.dad.treestore[tree_iter][4] == cons.RICH_TEXT_ID:
+            text_n_objects = self.html_get_from_treestore_node(tree_iter, sel_range)
+            self.images_count = 0
+            for i, html_slot in enumerate(text_n_objects[0]):
+                html_text += html_slot
+                if i < len(text_n_objects[1]):
+                    curr_object = text_n_objects[1][i]
+                    if curr_object[0] == "pixbuf":
+                        pix_dir = dir(curr_object[1][1])
+                        if "embfile" in pix_dir:
+                            html_text += self.get_embfile_html(curr_object[1], tree_iter)
+                        else:
+                            html_text += self.get_image_html(curr_object[1], tree_iter)
+                    elif curr_object[0] == "table": html_text += self.get_table_html(curr_object[1])
+                    elif curr_object[0] == "codebox": html_text += self.get_codebox_html(curr_object[1])
+        else: html_text += self.html_get_from_code_buffer(self.dad.treestore[tree_iter][2], sel_range)
+        if self.tree_links_text and not self.dad.last_index_in_page:
+            html_text += '<p align="center">' + '<img src="%s" height="22" width="22">' % os.path.join("images", "home.png") + 2*cons.CHAR_SPACE + '<a href="index.html">' + _("Index") + '</a></p>'
+        html_text += cons.HTML_FOOTER
+        node_html_filepath = os.path.join(self.new_path, self.get_html_filename(tree_iter))
+        #print "full=%s(prefix=%s)" % (len(node_html_filepath), len(self.new_path))
+        file_descriptor = open(node_html_filepath, 'w')
+        file_descriptor.write(html_text)
+        file_descriptor.close()
+
+    def node_export_to_html2(self, tree_iter, only_selection=False):
         """Export a Node To HTML"""
         if only_selection:
             iter_start, iter_end = self.dad.curr_buffer.get_selection_bounds()
@@ -678,8 +724,8 @@ class Export2Html:
             td_tree = r'<div class="main">'
             td_page = r'<div class="page">'
             html_text += td_tree + self.tree_links_text + td_page
-            if self.dad.last_include_node_name:
-                html_text += '<h1><b><u>%s</u></b></h1>' % clean_text_to_utf8(self.dad.treestore[tree_iter][1])
+        if self.dad.last_include_node_name:
+            html_text += '<h1><b><u>%s</u></b></h1>' % clean_text_to_utf8(self.dad.treestore[tree_iter][1])
         self.dad.get_textbuffer_from_tree_iter(tree_iter)
         if self.dad.treestore[tree_iter][4] == cons.RICH_TEXT_ID:
             text_n_objects = self.html_get_from_treestore_node(tree_iter, sel_range)
@@ -779,7 +825,6 @@ class Export2Html:
     def get_codebox_html(self, codebox):
         """Returns the HTML CodeBox"""
         # codebox is: [offset, dict, justification]
-        pango_font = pango.FontDescription(self.dad.code_font)
         codebox_align_text = self.get_object_alignment_string(codebox[2])
         codebox_html = '<div class="codebox">'
         codebox_html += codebox[1]['fill_text']
